build_auth_info

Function build_auth_info 

pub fn build_auth_info(
    public_key_bytes: &[u8],
    sequence: u64,
    fee: &Fee,
) -> Result<AuthInfo, String>
Build an AuthInfo structure for signing a Cosmos transaction.

Arguments

  • public_key_bytes - A byte slice representing the compressed secp256k1 public key (33 bytes).
  • sequence - The account sequence number for the signer.
  • fee - A reference to the transaction fee.

Returns

Returns Ok(AuthInfo) on success or an Err(String) describing the failure if the public key bytes are invalid.

Errors

Returns an error if the provided public key bytes are not a valid secp256k1 public key.